@@ -4,14 +4,12 @@
 /* ************************************************************************** */
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
-/* * file      : libmng_types.h            copyright (c) 2000 G.Juyn        * */
-/* * version   : 1.0.5                                                      * */
+/* * file      : libmng_types.h            copyright (c) 2000-2004 G.Juyn   * */
+/* * version   : 1.0.9                                                      * */
 /* *                                                                        * */
 /* * purpose   : type specifications                                        * */
 /* *                                                                        * */
 /* * author    : G.Juyn                                                     * */
-/* * web       : http://www.3-t.com                                         * */
-/* * email     : mailto:info@3-t.com                                        * */
 /* *                                                                        * */
 /* * comment   : Specification of the types used by the library             * */
 /* *             Creates platform-independant structure                     * */
@@ -103,6 +101,26 @@
 /* *             1.0.5 - 08/19/2002 - G.Juyn                                * */
 /* *             - B597134 - libmng pollutes the linker namespace           * */
 /* *                                                                        * */
+/* *             1.0.6 - 04/11/2003 - G.Juyn                                * */
+/* *             - B719420 - fixed several MNG_APP_CMS problems             * */
+/* *             1.0.6 - 06/15/2003 - R.Giles                               * */
+/* *             - lcms.h inclusion is generally no longer prefixed         * */
+/* *             1.0.6 - 07/07/2003 - G. R-P.                               * */
+/* *             - added png_imgtypes enumeration                           * */
+/* *                                                                        * */
+/* *             1.0.7 - 03/10/2004 - G.R-P                                 * */
+/* *             - added conditionals around openstream/closestream         * */
+/* *                                                                        * */
+/* *             1.0.8 - 04/11/2004 - G.Juyn                                * */
+/* *             - added data-push mechanisms for specialized decoders      * */
+/* *             1.0.8 - 08/01/2004 - G.Juyn                                * */
+/* *             - added support for 3+byte pixelsize for JPEG's            * */
+/* *                                                                        * */
+/* *             1.0.9 - 12/05/2004 - G.Juyn                                * */
+/* *             - inclusion of zlib/lcms/ijgsrc6b with <> instead of ""    * */
+/* *             1.0.9 - 12/06/2004 - G.Juyn                                * */
+/* *             - added conditional MNG_OPTIMIZE_CHUNKREADER               * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #ifndef _libmng_types_h_
@@ -148,14 +166,14 @@
 #endif
 
 #ifdef MNG_INCLUDE_ZLIB                /* zlib by Mark Adler & Jean-loup Gailly */
-#include "zlib.h"
+#include <zlib.h>
 #endif
 
 #ifdef MNG_INCLUDE_LCMS                /* little cms by Marti Maria Saguer */
 #ifndef ZLIB_DLL
 #undef FAR
 #endif
-#include "lcms.h"
+#include <lcms.h>
 #endif /* MNG_INCLUDE_LCMS */
 
 #ifdef MNG_INCLUDE_IJG6B               /* IJG's jpgsrc6b */
@@ -170,7 +188,8 @@
 #ifdef FAR
 #undef FAR                             /* possibly defined by zlib or lcms */
 #endif
-#include "jpeglib.h"                   /* all that for JPEG support  :-) */
+#define JPEG_INTERNAL_OPTIONS          /* for RGB_PIXELSIZE */
+#include <jpeglib.h>                   /* all that for JPEG support  :-) */
 #endif /* MNG_INCLUDE_IJG6B */
 
 #if defined(MNG_INTERNAL_MEMMNGMT) || defined(MNG_INCLUDE_FILTERS)
@@ -194,7 +213,7 @@
 #endif
 #endif /* WIN32 */
 
-#if defined(MNG_FULL_CMS) || defined(MNG_GAMMA_ONLY)
+#if defined(MNG_FULL_CMS) || defined(MNG_GAMMA_ONLY) || defined(MNG_APP_CMS)
 #include <math.h>                      /* fp gamma-calculation */
 #endif
 
@@ -377,6 +396,49 @@ typedef enum mng_imgtypes mng_imgtype;
 enum mng_speedtypes {mng_st_normal, mng_st_fast, mng_st_slow, mng_st_slowest};
 typedef enum mng_speedtypes mng_speedtype;
 
+#ifdef MNG_OPTIMIZE_CHUNKREADER
+                                       /* enumeration object-creation indicators */
+enum mng_createobjtypes {mng_create_none, mng_create_always, mng_create_ifglobal};
+typedef enum mng_createobjtypes mng_createobjtype;
+#endif
+
+/* ************************************************************************** */
+
+/* enumeration of PNG image types */
+#ifdef MNG_OPTIMIZE_FOOTPRINT_INIT
+enum png_imgtypes
+  {
+    png_g1,
+    png_g2,
+    png_g4,
+    png_g8,
+    png_rgb8,
+    png_idx1,
+    png_idx2,
+    png_idx4,
+    png_idx8,
+    png_ga8,
+    png_rgba8,
+#ifdef MNG_INCLUDE_JNG
+    png_jpeg_a1,
+    png_jpeg_a2,
+    png_jpeg_a4,
+    png_jpeg_a8,
+#endif
+#ifndef MNG_NO_16BIT_SUPPORT
+    png_g16,
+    png_ga16,
+    png_rgb16,
+    png_rgba16,
+#ifdef MNG_INCLUDE_JNG
+    png_jpeg_a16,
+#endif
+#endif
+    png_none
+  };
+    
+typedef enum png_imgtypes png_imgtype;
+#endif
 /* ************************************************************************** */
 
                                        /* memory management callbacks */
@@ -384,9 +446,15 @@ typedef mng_ptr    (MNG_DECL *mng_memalloc)      (mng_size_t  iLen);
 typedef void       (MNG_DECL *mng_memfree)       (mng_ptr     iPtr,
                                                   mng_size_t  iLen);
 
+typedef void       (MNG_DECL *mng_releasedata)   (mng_ptr     pUserdata,
+                                                  mng_ptr     pData,
+                                                  mng_size_t  iLength);
+
                                        /* I/O management callbacks */
+#ifndef MNG_NO_OPEN_CLOSE_STREAM
 typedef mng_bool   (MNG_DECL *mng_openstream)    (mng_handle  hHandle);
 typedef mng_bool   (MNG_DECL *mng_closestream)   (mng_handle  hHandle);
+#endif
 typedef mng_bool   (MNG_DECL *mng_readdata)      (mng_handle  hHandle,
                                                   mng_ptr     pBuf,
                                                   mng_uint32  iBuflen,
